@@ -6,6 +6,7 @@ from subprocess import call
 import os
 import pickle
 import imageio
+import sys
 
 
 #import matplotlib.pylab as plt
@@ -23,19 +24,20 @@ def get_root_folder(create_when_not_found=True):
         path='../'+path
     return './'
 
-def get_data_folder(create_when_not_found=True):
+def get_data_folder(create_when_not_found=True, default='./Data'):
     path='./'
     while os.path.isdir(path):
         if os.path.isdir(path+'Data/'):
             return os.path.abspath(path+'Data/').replace('\\', '/').replace('//', '/')
         path='../'+path
 
-    if not os.path.exists('./Data'):
-        try:
-            os.mkdir('./Data')
-        except:
-            print('was not able to create Data folder')
-    return './Data'
+    if default is not None:
+        if not os.path.exists(default):
+            try:
+                os.mkdir(default)
+            except:
+                print('was not able to create Data folder')
+    return default
     #raise Exception('No "Data" folder found above current working directory! Please create dirctory: ".../Project/Data".')
 
 def zipDir(dirPath, zipPath, filter=[]):
@@ -53,6 +55,20 @@ def zipDir(dirPath, zipPath, filter=[]):
                 zipf.write(filePath , filePath[lenDirPath :] )
     zipf.close()
 
+def add_project_root_path():
+    root = get_root_folder().replace('/', '\\')
+
+    #add root folder (folder that contains Data folder) to import paths for easier import management
+    if root not in sys.path:
+        sys.path.append(root)
+
+    # if project is a copy inside of a Data folder of the original project (e.g. Evolution_Project_Clones), ten remove the original folder from import paths
+    if '\\Data\\' in root:
+        original_project_folder = root[0:root.find('\\Data\\')]
+        if original_project_folder in sys.path:
+            sys.path.remove(original_project_folder)
+
+
 #searches for "Data" folder in project by default
 #default folder: .../Data/StorageManager/main_folder_name/folder_name/
 #example:
@@ -69,14 +85,16 @@ class StorageManager:
 
     def __init__(self, main_folder_name, folder_name=None, random_nr=False, print_msg=True, add_new_when_exists=True, data_folder=get_data_folder(), use_evolution_path=True):
 
+        #when evolution is active, all storage managers with use_evolution_path=True will automatically save all data in the right evolution folder
         if use_evolution_path:
-            import PymoNNto.Exploration.Evolution.Interface_Functions as evo_func
-            #if evo_func.get_gene('evo_name', None) is not None: # and evo_func.get_gene('gen', None) is not None and evo_func.get_gene('id', None) is not None
-            if 'evo_name' in evo_func.get_default_genome() and evo_func.get_default_genome()['evo_name'] is not None:
-                main_folder_name = evo_func.get_gene('evo_name', None)
-                folder_name = evo_func.get_gene_file(evo_func.evolution_genome)
-                #add_new_when_exists = True#??? Test
-                random_nr=False
+            import PymoNNto.Exploration.Evolution.Interface_Functions as I_func
+            evo_name = I_func.get_evo_name()
+            evo_id = I_func.get_evo_id()
+            if evo_name is not None and evo_id is not None:
+                main_folder_name = evo_name
+                folder_name = I_func.get_gene_file(evo_name, evo_id)
+                random_nr = False
+
 
         if type(main_folder_name) is dict:
             main_folder_name = self.dict_to_folder_name(main_folder_name)
@@ -311,7 +329,7 @@ class StorageManagerGroup:
         if os.path.exists(self.absolute_path):
             for folder in os.listdir(self.absolute_path):
                 if os.path.isdir(self.absolute_path+folder) and self.Tag in folder:
-                    self.StorageManagerList.append(StorageManager(self.Tag, folder, add_new_when_exists=False, data_folder=self.data_folder))
+                    self.StorageManagerList.append(StorageManager(self.Tag, folder, add_new_when_exists=False, data_folder=self.data_folder, use_evolution_path=False))
 
 
     def sort_by(self, param, section='Parameters'):
