@@ -1,6 +1,18 @@
+from PymoNNto.NetworkCore.Base_Attachable_Modules import *
 from PymoNNto.NetworkBehaviour.Recorder.Recorder import *
 import copy
 
+blue = (0.0, 0.0, 255.0, 255.0)
+red = (255.0, 0.0, 0.0, 255.0)
+green = (0.0, 200.0, 0.0, 255.0)
+yellow = (255.0, 255.0, 0.0, 255.0)
+purple = (255.0, 0.0, 255.0, 255.0)
+aqua = (0.0, 255.0, 255.0, 255.0)
+orange = (255.0, 150.0, 0.0, 255.0)
+black = (0.0, 0.0, 0.0, 255.0)
+white = (255.0, 255.0, 255.0, 255.0)
+
+
 class NeuronGroup(NetworkObjectBase):
 
     def __init__(self, size, behaviour, net, tag=None, color=None):
@@ -8,28 +20,26 @@ class NeuronGroup(NetworkObjectBase):
         if tag is None and net is not None:
             tag = 'NeuronGroup_'+str(len(net.NeuronGroups)+1)
 
-        super().__init__(tag=tag)
-        self.add_tag('ng')
-
-        self.BaseNeuronGroup = self#used for subgroup reconstruction
-
         if isinstance(size, Behaviour):
             if type(behaviour) is dict:
                 if 0 in behaviour:
                     print('warning: 0 index behaviour will be overwritten by size behaviour')
                 behaviour[0] = size
             if type(behaviour) is list:
-                behaviour.append(size)#first index???
-            size = -1
+                behaviour.insert(0, size)
+            size = -1#will be overwritten by size-behaviour
+
+        self.size = size
+
+        super().__init__(tag, net, behaviour)
+        self.add_tag('ng')
+
+        self.BaseNeuronGroup = self#used for subgroup reconstruction
 
         if net is not None:
             net.NeuronGroups.append(self)
-            self.network = net
             setattr(net, self.tags[0], self)
 
-
-        self.size = size
-
         self.afferent_synapses = {} #set by Network
         self.efferent_synapses = {}
 
@@ -38,71 +48,11 @@ class NeuronGroup(NetworkObjectBase):
         self.learning = True
         self.recording = True
 
-        self.behaviour = behaviour #Todo: Test without copy
-        #if type(behaviour) == list:
-        #    for i, b in enumerate(behaviour):
-        #        self.behaviour[i] = copy.copy(b)
-        #else:
-        #    for k in behaviour:
-        #        self.behaviour[k] = copy.copy(behaviour[k])
-
-        for k in sorted(list(self.behaviour.keys())):
-            if self.behaviour[k].set_variables_on_init:
-                self.behaviour[k].set_variables(self)
-
         self.id = np.arange(self.size)
 
         if color is not None:
             self.color = color
 
-    #do only use before initialization!!!
-    #after initialization use Netork.add_behaviours_to_neuron_group(...)
-    def add_behaviour(self, index, b, init=False):
-        self.behaviour[index] = copy.copy(b)
-        if init:
-            self.behaviour[index].set_variables(self)
-            self.behaviour[index].check_unused_attrs()
-        return self.behaviour[index]
-
-    def find_objects(self, key):
-        result = []
-
-        if key in self.behaviour:
-            result.append(self.behaviour[key])
-
-        for bk in self.behaviour:
-            behaviour = self.behaviour[bk]
-            result += behaviour[key]
-
-        #for syn_key in self.afferent_synapses:
-        #    for syn in self.afferent_synapses[syn_key]:
-        #        if syn not in result:
-        #            result += syn[key]
-
-        for am in self.analysis_modules:
-            result += am[key]
-
-        return result
-
-    def get_modification_value(self, key):
-        result = getattr(self, key)
-        if type(result) == np.ndarray:
-            return np.sum(result)
-        return result
-
-    def set_modification_value(self, key, value):
-        old_val = getattr(self, key)
-        if type(old_val) == np.ndarray:
-            mat_sum = np.sum(old_val)
-            if mat_sum == 0.0:
-                new = np.ones(old_val.shape)*value
-            else:
-                new = old_val/mat_sum*value
-            print('mat set to:', new)
-            return setattr(self, key, new)
-        else:
-            return setattr(self, key, value)
-
     def require_synapses(self, name, afferent=True, efferent=True, warning=True):
         if afferent and not name in self.afferent_synapses:
             if warning:
@@ -114,27 +64,12 @@ class NeuronGroup(NetworkObjectBase):
                 print('warning: no efferent {} synapses found'.format(name))
             self.efferent_synapses[name] = []
 
-    #def get_neuron_vec(self):
-    #    return self.get_nparray((self.size))
-
     def get_neuron_vec(self, mode='zeros()', scale=None, density=None, plot=False, kwargs={}, args=[]):# mode in ['zeros', 'zeros()', 'ones', 'ones()', 'uniform(...)', 'lognormal(...)', 'normal(...)', ...]
         return self._get_mat(mode=mode, dim=(self.size), scale=scale, density=density, plot=plot, kwargs=kwargs, args=args)
 
     def get_neuron_vec_buffer(self, buffer_size):
         return self.get_buffer_mat((self.size), buffer_size)
 
-    #def get_random_neuron_vec(self, density=1.0):#r
-    #    print("warning: use get_neuron_vec('uniform',...) instead of get_random_neuron_vec")
-    #    return self.get_random_nparray((self.size), density)
-
-    #def get_shared_variables(self, name, avoid_None=True):
-    #    result=[]
-    #    for k in self.behaviour:
-    #        val = self.behaviour[k].get_shared_variable(name)
-    #        if val!=None or avoid_None==False:
-    #            result.append(val)
-    #    return np.array(result)
-
     def get_combined_synapse_shape(self, Synapse_ID):
         source_num = 0
         for syn in self.afferent_synapses[Synapse_ID]:
@@ -190,7 +125,6 @@ class NeuronGroup(NetworkObjectBase):
         return result
 
     def partition_size(self, block_size=7):
-
         w = block_size#int((self.src.width/block_size+self.dst.width/block_size)/2)
         h = block_size#int((self.src.height/block_size+self.dst.height/block_size)/2)
         d = block_size#int((self.src.depth / block_size + self.dst.depth / block_size) / 2)
@@ -268,31 +202,6 @@ class NeuronGroup(NetworkObjectBase):
 
         md.show()
 
-    '''
-    def get_neuron_behaviour_parameter_list(self, neurons, param):
-        result = []
-        for k, b in neurons.behaviour.items():
-            if hasattr(b, param):
-                result.append(getattr(b, param))
-        return result
-
-    def get_connected_neuron_parameter_list(self, neurons, param, syn_tag='GLU', afferent=False, efferent=False, same_ng=False, search_behaviours=False):
-        result = []
-        if efferent:
-            for syn in neurons.efferent_synapses[syn_tag]:
-                if hasattr(syn.dst, param):
-                    result.append(getattr(syn.dst, param))
-
-        if afferent:
-            for syn in neurons.afferent_synapses[syn_tag]:
-                if hasattr(syn.src, param):
-                    result.append(getattr(syn.src, param))
-
-        return result
-            #max_buf = max(max_buf, syn.dst.input_buffer_requirement)
-        #neurons.output_buffer = neurons.get_neuron_vec_buffer(max_buf)
-    '''
-
 
 class NeuronSubGroup:
 
@@ -309,14 +218,6 @@ class NeuronSubGroup:
         else:
             return var[self.mask]
 
-    #def get_masked_dict(self, dict_name, key):
-    #    attr=getattr(self.BaseNeuronGroup, dict_name)[key]
-    #    self.mask_var(attr)
-    #    #if attr.shape[0] != self.mask.shape[0]:
-    #    #    return attr[:, self.mask]
-    #    #else:
-    #    #    return attr[self.mask]
-
     def __getattr__(self, attr_name):
         if attr_name in ['BaseNeuronGroup', 'mask', 'cache', 'key_id_cache', 'id_mask']:
             return super().__getattr__(attr_name)#setattr
@@ -324,24 +225,9 @@ class NeuronSubGroup:
         if attr_name == 'size':
             return np.sum(self.mask)
 
-        #print('request', attr_name,hasattr(self.BaseNeuronGroup, 'tf'))
-
         attr = getattr(self.BaseNeuronGroup, attr_name)
         if type(attr) == np.ndarray:
 
-            #attr_id = id(attr)
-            #if not attr_id in self.cache:
-            #    if attr_name in self.key_id_cache:#remove unused cache data
-            #        self.cache.pop(self.key_id_cache[attr_name])
-            #    if attr.shape[0] != self.mask.shape[0]:
-            #        self.cache[attr_id] = attr[:, self.mask]
-            #    else:
-            #        self.cache[attr_id] = attr[self.mask]
-            #    self.key_id_cache[attr_name] = attr_id
-            #return self.cache[attr_id]
-
-            #self.mask_var(attr)
-
             if attr.shape[0] != self.mask.shape[0]:
                 return attr[:, self.mask]
             else:
@@ -362,28 +248,9 @@ class NeuronSubGroup:
             super().__setattr__(attr_name, value)
             return
 
-        #if len(self.BaseNeuronGroup['TF']) > 0 and not hasattr(self, 'tf'):
-        #    import tensorflow as tf
-        #    self.tf=tf
-
-        #print(self.BaseNeuronGroup.__dict__)
-
         attr = getattr(self.BaseNeuronGroup, attr_name)
         if type(attr) == np.ndarray:
 
-            #attr_id = id(attr)
-            #if not attr_id in self.cache:
-            #    if attr_name in self.key_id_cache:  # remove unused cache data
-            #        self.cache.pop(self.key_id_cache[attr_name])
-            #    if attr.shape[0] != self.mask.shape[0]:
-            #        self.cache[attr_id] = attr[:, self.mask]
-            #    else:
-            #        self.cache[attr_id] = attr[self.mask]
-            #    self.key_id_cache[attr_name] = attr_id
-            #self.cache[attr_id] = value
-
-            #self.mask_var(attr)[:] = value
-
             if attr.shape[0] != self.mask.shape[0]:
                 attr[:, self.mask] = value
             else:
@@ -392,12 +259,9 @@ class NeuronSubGroup:
         elif hasattr(self.BaseNeuronGroup, 'tf') and (type(attr) == self.BaseNeuronGroup.tf.python.ops.resource_variable_ops.ResourceVariable or type(attr) == self.BaseNeuronGroup.tf.python.framework.ops.EagerTensor):
             if attr.shape[0] != self.mask.shape[0]:
                 self.BaseNeuronGroup.tf.compat.v1.scatter_update(attr, [np.newaxis, self.id_mask], value)
-                #setattr(self.BaseNeuronGroup, attr_name, self.BaseNeuronGroup.tf.compat.v1.scatter_update(attr, [np.newaxis, self.id_mask], value))
             else:
-                #setattr(self.BaseNeuronGroup, attr_name, self.BaseNeuronGroup.tf.compat.v1.scatter_update(attr, [self.id_mask], value))
                 self.BaseNeuronGroup.tf.compat.v1.scatter_update(attr, [self.id_mask], value)
 
-
         else:
             setattr(self.BaseNeuronGroup, attr, value)
 
