@@ -1,3 +1,4 @@
+import numpy as np
 from PymoNNto.NetworkCore.Network import *
 from PymoNNto.NetworkCore.Behaviour import *
 from PymoNNto.NetworkCore.Neuron_Group import *
@@ -9,3 +10,11 @@ from PymoNNto.NetworkBehaviour.Structure.Receptive_Fields import *
 from PymoNNto.NetworkBehaviour.Recorder.Recorder import *
 from PymoNNto.Exploration.HelperFunctions import *
 from PymoNNto.Exploration.StorageManager.StorageManager import *
+
+#convenience functions:
+
+#add root project folder to import path
+add_project_root_path()
+
+#print numpy arrays with commas for easier copy paste
+np.set_string_function(lambda x: repr(x), repr=False) 
\ No newline at end of file
